@@ -134,6 +134,8 @@ def playability_status(watch_html: str) -> (str, str):
     """
     player_response = initial_player_response(watch_html)
     status_dict = player_response.get('playabilityStatus', {})
+    if 'liveStreamability' in status_dict:
+        return 'LIVE_STREAM', 'Video is a live stream.'
     if 'status' in status_dict:
         if 'reason' in status_dict:
             return status_dict['status'], [status_dict['reason']]
@@ -193,16 +195,17 @@ def channel_name(url: str) -> str:
         YouTube channel name.
     """
     patterns = [
-        r"(?:\/c\/([\d\w_\-]+)(\/.*)?)",
-        r"(?:\/channel\/([\w\d_\-]+)(\/.*)?)"
+        r"(?:\/(c)\/([\d\w_\-]+)(\/.*)?)",
+        r"(?:\/(channel)\/([\w\d_\-]+)(\/.*)?)"
     ]
     for pattern in patterns:
         regex = re.compile(pattern)
         function_match = regex.search(url)
         if function_match:
             logger.debug("finished regex search, matched: %s", pattern)
-            channel_id = function_match.group(1)
-            return channel_id
+            uri_style = function_match.group(1)
+            uri_identifier = function_match.group(2)
+            return f'/{uri_style}/{uri_identifier}'
 
     raise RegexMatchError(
         caller="channel_name", pattern="patterns"
